=====
pyrsr
=====

A package providing relative spectral response functions for remote sensing instruments.

* Free software: GNU General Public License v3
* Documentation: http://geomultisens.gitext.gfz-potsdam.de/pyrsr/doc/
* Submit feedback by filing an issue `here <https://gitext.gfz-potsdam.de/geomultisens/pyrsr/issues>`__.


Status
------

.. image:: https://gitext.gfz-potsdam.de/geomultisens/pyrsr/badges/master/build.svg
        :target: https://gitext.gfz-potsdam.de/geomultisens/pyrsr/commits/master
.. image:: https://gitext.gfz-potsdam.de/geomultisens/pyrsr/badges/master/coverage.svg
        :target: http://geomultisens.gitext.gfz-potsdam.de/pyrsr/coverage/
.. image:: https://img.shields.io/pypi/v/pyrsr.svg
        :target: https://pypi.python.org/pypi/pyrsr
.. image:: https://img.shields.io/pypi/l/pyrsr.svg
        :target: https://gitext.gfz-potsdam.de/geomultisens/pyrsr/blob/master/LICENSE
.. image:: https://img.shields.io/pypi/pyversions/pyrsr.svg
        :target: https://img.shields.io/pypi/pyversions/pyrsr.svg
.. .. image:: https://img.shields.io/travis/danschef/pyrsr.svg
        :target: https://travis-ci.org/danschef/pyrsr
.. .. image:: https://readthedocs.org/projects/pyrsr/badge/?version=latest
        :target: https://pyrsr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
.. .. image:: https://pyup.io/repos/github/danschef/pyrsr/shield.svg
     :target: https://pyup.io/repos/github/danschef/pyrsr/
     :alt: Updates

See also the latest coverage_ report and the nosetests_ HTML report.


Features
--------

* TODO

Credits
-------

The pyrsr package was developed within the context of the GeoMultiSens project funded
by the German Federal Ministry of Education and Research (project grant code: 01 IS 14 010 A-C).

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _coverage: http://geomultisens.gitext.gfz-potsdam.de/pyrsr/coverage/
.. _nosetests: http://geomultisens.gitext.gfz-potsdam.de/pyrsr/nosetests_reports/nosetests.html
